@@ -1,13 +1,13 @@
 """Benchmarks the file handler with unicode"""
-from logbook import Logger, FileHandler
 from tempfile import NamedTemporaryFile
 
+from logbook import FileHandler, Logger
 
-log = Logger('Test logger')
+log = Logger("Test logger")
 
 
 def run():
     f = NamedTemporaryFile()
     with FileHandler(f.name) as handler:
-        for x in xrange(500):
-            log.warning(u'this is handled \x6f')
+        for x in range(500):
+            log.warning("this is handled \x6f")
