@@ -1,9 +1,8 @@
 """Tests with a logging handler becoming a noop for comparison"""
-from logging import getLogger, StreamHandler, ERROR
-from cStringIO import StringIO
+from io import StringIO
+from logging import ERROR, StreamHandler, getLogger
 
-
-log = getLogger('Testlogger')
+log = getLogger("Testlogger")
 log.setLevel(ERROR)
 
 
@@ -11,5 +10,5 @@ def run():
     out = StringIO()
     handler = StreamHandler(out)
     log.addHandler(handler)
-    for x in xrange(500):
-        log.warning('this is not handled')
+    for x in range(500):
+        log.warning("this is not handled")
