@@ -1,9 +1,8 @@
 """Tests with a filter disabling a handler for comparsion in logging"""
-from logging import getLogger, StreamHandler, Filter
-from cStringIO import StringIO
+from io import StringIO
+from logging import Filter, StreamHandler, getLogger
 
-
-log = getLogger('Testlogger')
+log = getLogger("Testlogger")
 
 
 class DisableFilter(Filter):
@@ -16,5 +15,5 @@ def run():
     handler = StreamHandler(out)
     handler.addFilter(DisableFilter())
     log.addHandler(handler)
-    for x in xrange(500):
-        log.warning('this is not handled')
+    for x in range(500):
+        log.warning("this is not handled")
