@@ -1,8 +1,8 @@
 """Tests basic stack manipulation performance"""
-from logbook import Handler, NullHandler, StreamHandler, FileHandler, \
-    ERROR, WARNING
+from io import StringIO
 from tempfile import NamedTemporaryFile
-from cStringIO import StringIO
+
+from logbook import ERROR, WARNING, FileHandler, Handler, NullHandler, StreamHandler
 
 
 def run():
@@ -11,5 +11,5 @@ def run():
     with NullHandler():
         with StreamHandler(out, level=WARNING):
             with FileHandler(f.name, level=ERROR):
-                for x in xrange(100):
+                for x in range(100):
                     list(Handler.stack_manager.iter_context_objects())
