@@ -1,12 +1,10 @@
-import pytest
-import logbook
 import asyncio
-from logbook.concurrency import has_contextvars
+
+import logbook
 
 ITERATIONS = 100
 
 
-@pytest.mark.skipif(not has_contextvars, reason="Contexvars not available")
 def test_asyncio_context_management(logger):
     h1 = logbook.TestHandler()
     h2 = logbook.TestHandler()
@@ -18,10 +16,13 @@ def test_asyncio_context_management(logger):
 
             await asyncio.sleep(0)  # allow for context switch
 
-    asyncio.get_event_loop().run_until_complete(asyncio.gather(task(h1, 'task1'), task(h2, 'task2')))
+    async def main():
+        await asyncio.gather(task(h1, "task1"), task(h2, "task2"))
+
+    asyncio.run(main())
 
     assert len(h1.records) == ITERATIONS
-    assert all(['task1' == r.msg for r in h1.records])
+    assert all(["task1" == r.msg for r in h1.records])
 
     assert len(h2.records) == ITERATIONS
-    assert all(['task2' == r.msg for r in h2.records])
+    assert all(["task2" == r.msg for r in h2.records])
